@@ -20,7 +20,6 @@ from unittest import mock
 
 import ddt
 from oslo_utils.fixture import uuidsentinel
-import six
 
 from tackerclient.common import exceptions
 from tackerclient.osc import utils as tacker_osc_utils
@@ -115,7 +114,7 @@ class TestCreateVnfLcm(TestVnfLcm):
         if instantiate:
             self.assertEqual(expected_message, buffer.getvalue().strip())
 
-        self.assertItemsEqual(_get_columns_vnflcm(),
+        self.assertCountEqual(_get_columns_vnflcm(),
                               actual_columns)
         self.assertListItemsEqual(vnflcm_fakes.get_vnflcm_data(
             json, columns=attributes), data)
@@ -145,7 +144,7 @@ class TestShowVnfLcm(TestVnfLcm):
             json=vnf_instance, headers=self.header)
 
         columns, data = (self.show_vnf_lcm.take_action(parsed_args))
-        self.assertItemsEqual(_get_columns_vnflcm(action='show'),
+        self.assertCountEqual(_get_columns_vnflcm(action='show'),
                               columns)
         headers, attributes = vnflcm._get_columns(vnf_instance, action='show')
         self.assertListItemsEqual(
@@ -177,9 +176,9 @@ class TestListVnfLcm(TestVnfLcm):
             expected_data.append(vnflcm_fakes.get_vnflcm_data(
                 vnf_instance_obj, columns=columns, list_action=True))
 
-        self.assertItemsEqual(_get_columns_vnflcm(action='list'),
+        self.assertCountEqual(_get_columns_vnflcm(action='list'),
                               actual_columns)
-        self.assertItemsEqual(expected_data, list(data))
+        self.assertCountEqual(expected_data, list(data))
 
 
 class TestInstantiateVnfLcm(TestVnfLcm):
@@ -448,7 +447,7 @@ class TestTerminateVnfLcm(TestVnfLcm):
                                 "delete vnf instance %(id)s"
                                 % {'timeout': 15, 'id': vnf_instance['id']})
 
-            self.assertIn(expected_message, six.text_type(result))
+            self.assertIn(expected_message, str(result))
             self.assertNotCalled(mock_delete)
 
     def test_terminate_no_options(self):
@@ -554,3 +553,157 @@ class TestDeleteVnfLcm(TestVnfLcm):
 
         self.assertEqual('Failed to delete 1 of 3 vnf instances.',
                          exception.message)
+
+
+class TestUpdateVnfLcm(TestVnfLcm):
+    def setUp(self):
+        super(TestUpdateVnfLcm, self).setUp()
+        self.update_vnf_lcm = vnflcm.UpdateVnfLcm(
+            self.app, self.app_args, cmd_name='vnflcm modify')
+
+    def test_take_action(self):
+        vnf_instance = vnflcm_fakes.vnf_instance_response()
+        sample_param_file = ("./tackerclient/osc/v1/vnflcm/samples/"
+                             "update_vnf_instance_param_sample.json")
+
+        arglist = [vnf_instance['id'], '--I', sample_param_file]
+        verifylist = [('vnf_instance', vnf_instance['id']),
+                      ('I', sample_param_file)]
+
+        # command param
+        parsed_args = self.check_parser(
+            self.update_vnf_lcm, arglist, verifylist)
+        url = os.path.join(
+            self.url,
+            'vnflcm/v1/vnf_instances',
+            vnf_instance['id'])
+
+        self.requests_mock.register_uri(
+            'PATCH', url, headers=self.header, json={})
+
+        sys.stdout = buffer = StringIO()
+        self.update_vnf_lcm.take_action(parsed_args)
+
+        actual_message = buffer.getvalue().strip()
+
+        expected_message = ('Update vnf:' + vnf_instance['id'])
+
+        self.assertEqual(expected_message, actual_message)
+
+    def test_take_action_param_file_not_exists(self):
+        vnf_instance = vnflcm_fakes.vnf_instance_response()
+        sample_param_file = "./not_exists.json"
+        arglist = [vnf_instance['id'], '--I', sample_param_file]
+        verifylist = [('vnf_instance', vnf_instance['id']),
+                      ('I', sample_param_file)]
+
+        # command param
+        parsed_args = self.check_parser(self.update_vnf_lcm, arglist,
+                                        verifylist)
+
+        self.assertRaises(exceptions.InvalidInput,
+                          self.update_vnf_lcm.take_action, parsed_args)
+
+
+@ddt.ddt
+class TestScaleVnfLcm(TestVnfLcm):
+    def setUp(self):
+        super(TestScaleVnfLcm, self).setUp()
+        self.scale_vnf_lcm = vnflcm.ScaleVnfLcm(
+            self.app, self.app_args, cmd_name='vnflcm scale')
+
+    @ddt.data('SCALE_IN', 'SCALE_OUT')
+    def test_take_action(self, scale_type):
+        vnf_instance = vnflcm_fakes.vnf_instance_response()
+        sample_param_file = ("./tackerclient/osc/v1/vnflcm/samples/"
+                             "scale_vnf_instance_param_sample.json")
+
+        arglist = [vnf_instance['id'],
+                   '--aspect-id', uuidsentinel.aspect_id,
+                   '--number-of-steps', '1',
+                   '--type', scale_type,
+                   '--additional-param-file', sample_param_file]
+        verifylist = [('vnf_instance', vnf_instance['id']),
+                      ('aspect_id', uuidsentinel.aspect_id),
+                      ('number_of_steps', 1),
+                      ('type', scale_type),
+                      ('additional_param_file', sample_param_file)]
+
+        # command param
+        parsed_args = self.check_parser(self.scale_vnf_lcm, arglist,
+                                        verifylist)
+        url = os.path.join(
+            self.url,
+            'vnflcm/v1/vnf_instances',
+            vnf_instance['id'],
+            'scale')
+
+        self.requests_mock.register_uri(
+            'POST', url, headers=self.header, json={})
+
+        sys.stdout = buffer = StringIO()
+        self.scale_vnf_lcm.take_action(parsed_args)
+
+        actual_message = buffer.getvalue().strip()
+
+        expected_message = ("Scale request for VNF Instance %s has been "
+                            "accepted.") % vnf_instance['id']
+
+        self.assertEqual(expected_message, actual_message)
+
+    @ddt.data('SCALE_IN', 'SCALE_OUT')
+    def test_take_action_param_file_not_exists(self, scale_type):
+        vnf_instance = vnflcm_fakes.vnf_instance_response()
+        sample_param_file = "./not_exists.json"
+        arglist = [vnf_instance['id'],
+                   '--aspect-id', uuidsentinel.aspect_id,
+                   '--number-of-steps', '2',
+                   '--type', scale_type,
+                   '--additional-param-file', sample_param_file]
+        verifylist = [('vnf_instance', vnf_instance['id']),
+                      ('aspect_id', uuidsentinel.aspect_id),
+                      ('number_of_steps', 2),
+                      ('type', scale_type),
+                      ('additional_param_file', sample_param_file)]
+
+        # command param
+        parsed_args = self.check_parser(self.scale_vnf_lcm, arglist,
+                                        verifylist)
+
+        ex = self.assertRaises(exceptions.InvalidInput,
+                               self.scale_vnf_lcm.take_action, parsed_args)
+
+        expected_msg = ("Invalid input: File %s does not exist "
+                        "or user does not have read privileges to it")
+        self.assertEqual(expected_msg % sample_param_file, str(ex))
+
+    @ddt.data('SCALE_IN', 'SCALE_OUT')
+    def test_take_action_vnf_instance_not_found(self, scale_type):
+        vnf_instance = vnflcm_fakes.vnf_instance_response()
+        sample_param_file = ("./tackerclient/osc/v1/vnflcm/samples/"
+                             "update_vnf_instance_param_sample.json")
+        arglist = [vnf_instance['id'],
+                   '--aspect-id', uuidsentinel.aspect_id,
+                   '--number-of-steps', '3',
+                   '--type', scale_type,
+                   '--additional-param-file', sample_param_file]
+        verifylist = [('vnf_instance', vnf_instance['id']),
+                      ('aspect_id', uuidsentinel.aspect_id),
+                      ('number_of_steps', 3),
+                      ('type', scale_type),
+                      ('additional_param_file', sample_param_file)]
+
+        # command param
+        parsed_args = self.check_parser(self.scale_vnf_lcm, arglist,
+                                        verifylist)
+
+        url = os.path.join(
+            self.url,
+            'vnflcm/v1/vnf_instances',
+            vnf_instance['id'])
+        self.requests_mock.register_uri(
+            'POST', url, headers=self.header, status_code=404, json={})
+
+        self.assertRaises(exceptions.TackerClientException,
+                          self.scale_vnf_lcm.take_action,
+                          parsed_args)
